"use strict";
var core_1 = require('@angular/core');
var moment = require('moment');
var DatePickerContainerComponent = (function () {
    function DatePickerContainerComponent(elRef, zone) {
        var _this = this;
        this.elRef = elRef;
        this.zone = zone;
        this.onDateSelected = new core_1.EventEmitter();
        this.opened = false;
        this.date = moment();
        this.days = [];
        this.options = {};
        this.watchMediaQuery = function (mql) {
            _this.zone.run(function () {
                _this.mqMatches = _this.mq.matches ? true : false;
            });
        };
    }
    DatePickerContainerComponent.prototype.mergeOptions = function (options) {
        Object.assign(this.options, options);
    };
    DatePickerContainerComponent.prototype.generateCalendar = function (selectedMonthFlag) {
        this.weekDayNames = moment.weekdaysShort();
        if (!this.firstWeekdaySunday) {
            this.weekDayNames.splice(6, 0, this.weekDayNames.splice(0, 1)[0]);
        }
        this.date = selectedMonthFlag && this.inputDate ? this.inputDate.clone() : moment(this.date);
        var month = this.date.month();
        var firstDay = this.date.clone().startOf('month');
        var offset = null;
        if (this.firstWeekdaySunday) {
            offset = firstDay.day() === 0 ? 7 : firstDay.day();
        }
        else {
            offset = firstDay.day() === 0 ? 6 : firstDay.day() - 1;
        }
        var daysInMonth = this.date.daysInMonth();
        var rows = Math.ceil((offset + daysInMonth) / 7);
        this.weeks = [];
        var currentDate = firstDay.subtract(offset, 'day');
        var selectedDate = this.inputDate;
        for (var i = 1; i <= rows; i += 1) {
            var days = [];
            for (var i_1 = 1; i_1 <= 7; i_1 += 1) {
                var today = (moment().isSame(currentDate, 'day') && moment().isSame(currentDate, 'month')) ? true : false;
                var weekend = (moment(currentDate).day() == 6) || (moment(currentDate).day() == 0);
                var selected = (selectedDate && selectedDate.isSame(currentDate, 'day')) ? true : false;
                days.push({
                    day: currentDate.date(),
                    month: currentDate.month() + 1,
                    year: currentDate.year(),
                    enabled: true,
                    differentMonth: month === currentDate.month(),
                    today: today,
                    weekend: weekend,
                    selected: selected
                });
                currentDate.add(1, 'day');
            }
            this.weeks.push({ rowId: i, days: days });
        }
    };
    DatePickerContainerComponent.prototype.setToday = function () {
        var today = moment();
        this.inputDate = today;
        this.generateCalendar(true);
        this.onDateSelected.emit(this.inputDate);
    };
    DatePickerContainerComponent.prototype.selectDate = function (e, d) {
        e.preventDefault();
        this.inputDate = moment(d.day + "." + d.month + "." + d.year, 'DD.MM.YYYY');
        this.generateCalendar(true);
        this.onDateSelected.emit(this.inputDate);
    };
    DatePickerContainerComponent.prototype.prevMonth = function () {
        this.date = this.date.subtract(1, 'month');
        this.generateCalendar();
    };
    DatePickerContainerComponent.prototype.nextMonth = function () {
        this.date = this.date.add(1, 'month');
        this.generateCalendar();
    };
    DatePickerContainerComponent.prototype.open = function () {
        this.opened = true;
        this.generateCalendar(true);
        if (this.options.modalMediaQuery) {
            this.mq = window.matchMedia("(" + this.options.modalMediaQuery + ")");
            this.mqMatches = this.mq.matches ? true : false;
            this.mq.addListener(this.watchMediaQuery);
        }
    };
    DatePickerContainerComponent.prototype.close = function () {
        this.opened = false;
        if (this.mq) {
            this.mq.removeListener(this.watchMediaQuery);
        }
    };
    DatePickerContainerComponent.prototype.ngOnDestroy = function () {
        if (this.mq) {
            this.mq.removeListener(this.watchMediaQuery);
        }
    };
    DatePickerContainerComponent.decorators = [
        { type: core_1.Component, args: [{
                    // moduleId: module.id,
                    selector: 'jb-datepicker-container',
                    templateUrl: './datepicker-container.component.html',
                    styleUrls: ['./datepicker-container.component.css'],
                    animations: [
                        core_1.trigger('contentAnimation', [
                            core_1.transition('void => *', [
                                core_1.style({ opacity: '0' }),
                                core_1.animate('200ms ease-in')
                            ]),
                            core_1.transition('* => void', [
                                core_1.animate('300ms ease-out', core_1.style({ opacity: '0' }))
                            ])
                        ])
                    ]
                },] },
    ];
    /** @nocollapse */
    DatePickerContainerComponent.ctorParameters = [
        { type: core_1.ElementRef, },
        { type: core_1.NgZone, },
    ];
    DatePickerContainerComponent.propDecorators = {
        'onDateSelected': [{ type: core_1.Output },],
    };
    return DatePickerContainerComponent;
}());
exports.DatePickerContainerComponent = DatePickerContainerComponent;
//# sourceMappingURL=datepicker-container.component.js.map