"use strict";
var core_1 = require('@angular/core');
var datepicker_options_1 = require('../datepicker-options');
var moment = require('moment');
var DatePickerComponent = (function () {
    function DatePickerComponent(elRef, opts) {
        var _this = this;
        this.elRef = elRef;
        this.opts = opts;
        this.options = {};
        this.date = moment();
        this.viewDate = null;
        this.days = [];
        this.disabled = false;
        this.onTouchedCallback = function () { };
        this.onChangeCallback = function () { };
        this.closePickerOnOutsideClick = function (event) { return _this.close(event); };
        this.closePickerOnTab = function (event) { return _this.closeOnTab(event); };
    }
    Object.defineProperty(DatePickerComponent.prototype, "value", {
        get: function () {
            return this.viewDate;
        },
        set: function (value) {
            var date = (value instanceof moment) ? value : moment(value, this.options.format);
            this.viewDate = date.isValid() ? date.format(this.options.viewFormat) : value;
        },
        enumerable: true,
        configurable: true
    });
    DatePickerComponent.prototype.setDisabledState = function (isDisabled) {
        this.disabled = isDisabled;
    };
    DatePickerComponent.prototype.onDateSelected = function (date) {
        this.value = date;
        this.onChangeCallback(date.format(this.options.format));
        if (this.options.closeOnSelect) {
            this.close();
        }
    };
    DatePickerComponent.prototype.ngOnInit = function () {
        if (this.opts) {
            if (typeof this.options.format === 'undefined') {
                this.options.format = this.opts.format;
            }
            if (typeof this.options.viewFormat === 'undefined') {
                this.options.viewFormat = this.opts.viewFormat;
            }
            if (typeof this.options.modalMediaQuery === 'undefined') {
                this.options.modalMediaQuery = this.opts.modalMediaQuery;
            }
            if (typeof this.options.firstWeekdaySunday === 'undefined') {
                this.options.firstWeekdaySunday = this.opts.firstWeekdaySunday;
            }
            else {
                this.options.firstWeekdaySunday = this.options.firstWeekdaySunday.toString() === 'true';
            }
            if (typeof this.options.todayString === 'undefined') {
                this.options.todayString = this.opts.todayString;
            }
            if (typeof this.options.todayButtonEnabled === 'undefined') {
                this.options.todayButtonEnabled = this.opts.todayButtonEnabled;
            }
            else {
                this.options.todayButtonEnabled = this.options.todayButtonEnabled.toString() === 'true';
            }
            if (typeof this.options.todayHighlight === 'undefined') {
                this.options.todayHighlight = this.opts.todayHighlight;
            }
            else {
                this.options.todayHighlight = this.options.todayHighlight.toString() === 'true';
            }
            if (typeof this.options.weekendHighlight === 'undefined') {
                this.options.weekendHighlight = this.opts.weekendHighlight;
            }
            else {
                this.options.weekendHighlight = this.options.weekendHighlight.toString() === 'true';
            }
            if (typeof this.options.closeOnSelect === 'undefined') {
                this.options.closeOnSelect = this.opts.closeOnSelect;
            }
            else {
                this.options.closeOnSelect = this.options.closeOnSelect.toString() === 'true';
            }
        }
        this.datePicker.mergeOptions(this.options);
    };
    DatePickerComponent.prototype.ngAfterViewInit = function () {
        if (this.opened) {
            this.datePicker.open();
        }
    };
    DatePickerComponent.prototype.writeValue = function (value) {
        this.viewDate = value;
    };
    DatePickerComponent.prototype.registerOnChange = function (fn) {
        this.onChangeCallback = fn;
    };
    DatePickerComponent.prototype.registerOnTouched = function (fn) {
        this.onTouchedCallback = fn;
    };
    DatePickerComponent.prototype.toggle = function () {
        if (!this.datePicker.opened) {
            this.open();
        }
        else {
        }
    };
    DatePickerComponent.prototype.closeOnTab = function (event) {
        if (event.keyCode === 9) {
            if (this.viewDate) {
                this.value = moment(this.viewDate, this.options.viewFormat);
            }
            this.onTouchedCallback();
            this.close();
        }
    };
    DatePickerComponent.prototype.open = function (event) {
        if (this.disabled) {
            console.log('Input is disabled');
            return;
        }
        if (event) {
            event.preventDefault();
        }
        var date = moment(this.value, this.options.viewFormat);
        this.datePicker.inputDate = date.isValid() ? date : null;
        this.datePicker.open();
        window.addEventListener('click', this.closePickerOnOutsideClick, true);
        window.addEventListener('keydown', this.closePickerOnTab, true);
    };
    DatePickerComponent.prototype.close = function (event) {
        if (event) {
            if (this.elRef.nativeElement.contains(event.target)) {
                return;
            }
            event.stopImmediatePropagation();
        }
        this.onTouchedCallback();
        window.removeEventListener('keydown', this.closePickerOnTab, true);
        window.removeEventListener('click', this.closePickerOnOutsideClick, true);
        this.datePicker.close();
    };
    DatePickerComponent.prototype.ngOnDestroy = function () {
        window.removeEventListener('keydown', this.closePickerOnTab, true);
        window.removeEventListener('click', this.closePickerOnOutsideClick, true);
    };
    DatePickerComponent.decorators = [
        { type: core_1.Component, args: [{
                    selector: '',
                    template: ''
                },] },
    ];
    /** @nocollapse */
    DatePickerComponent.ctorParameters = [
        { type: core_1.ElementRef, },
        { type: datepicker_options_1.AngularDatepickerOptions, },
    ];
    DatePickerComponent.propDecorators = {
        'class': [{ type: core_1.Input },],
        'opened': [{ type: core_1.Input },],
        'options': [{ type: core_1.Input },],
    };
    return DatePickerComponent;
}());
exports.DatePickerComponent = DatePickerComponent;
//# sourceMappingURL=datepicker.js.map